#
# spec file for package antlr-bootstrap (Version 2.7.7)
#
# Copyright (c) 2009 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           antlr-bootstrap
%define non_bootstrap_name antlr
BuildRequires:  fastjar gcc-gij gcc-java unzip zip
BuildRequires:  ecj-bootstrap >= 0.570
Provides:       antlr
%if %{?mandriva_release:1}0
%endif
%define       real_name antlr
Summary:        Antlr for bootstrapping purposes
Version:        2.7.7
Release:        71.1.moblin2
Url:            http://www.antlr.org
Group:          Development/Libraries/Java
License:        BSD 3-Clause; Public Domain, Freeware
AutoReqProv:    on
Source0:        antlr-%{version}.tar.bz2
Source1:        manifest.antlr
# files for the source package
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description 
This antlr package is used for bootstrapping purposes only.



Authors:
--------
    This antlr package is used for bootstrapping purposes only.

%prep 
#<<< package descriptions end
#>>>
# antlr
%setup -n %{real_name}-%{version}
find | grep "\(ShowString.java$\|StreamConverter.java$\)" && exit 42
#<<<
#>>> %build 

%build 
#>>> some useful functions ... used throughout bootstrap packages
# variables:
TARGET_DIR=`pwd`
CLASSPATH_ORIG="$CLASSPATH"
LIB_GCJ="`ls %{_javadir}/libgcj-*.jar`"
#>>> delete binary file and files not needed
function delBinaryFiles() {
  set +x
  echo deleting binary files ...
  for file in `find . -name "*.class" -o -name "*.jar" -o -name "*DELETED-BY-PACKAGER*"` 
  do 
    rm -rf $file
  done
  set -x
}
#<<<
#>>> make a string with all jar files found in target folder that can be used for a classpath string
# string is saved in JAR_CLASSPATH
function mkTargetClasspath() {
  set +x
  JAR_CLASSPATH=""
  for file in `find %{_javadir} -name "*.jar"`
  do
    JAR_CLASSPATH=$file:$JAR_CLASSPATH
  done
  set -x
}
#<<<
#>>> compiles all *.java file in the current directory tree
# uses mkTargetClasspath for CLASSPATH  variable
# uses LIB_GCJ for CLASSPATH
function compileFiles() {
  mkTargetClasspath
  set +x
  COMPILE_CLASSPATH_PATH=.:${JAR_CLASSPATH}
  echo using: $COMPILER_COMMAND $COMPILE_CLASSPATH_PATH $$file
  for file in `find . -name "*.java"`
  do
    echo -e "$COMPILER_COMMAND $COMPILE_CLASSPATH_PATH $file ... \c"
    $COMPILER_COMMAND $COMPILE_CLASSPATH_PATH $file
    # check for errors
    if [ $? != 0 ]
    then
      echo ERROR
      exit 1;
    fi
    echo done
  done
  set -x
}
#<<<
#>>> make jar archive
# PARAM#1: name of jar archive (without .jar suffix)
# uses $TARGET_DIR to move created jar to
function mkJar() {
  find  -name "version.txt" -or -name "*.class" -or -name "*.properties" -or -name "*.rsc" -or -name "*manifest*" |\
    xargs /usr/bin/fastjar -m manifest.* -cf ${1}.jar ;
  mv ${1}.jar $TARGET_DIR
}
#<<<
COMPILER_COMMAND="gij -jar %{_javadir}/jdtcore.jar -cp  "
#<<< end functions
delBinaryFiles
#>>> antlr
mkdir src
mv antlr src
cd src
cp %{SOURCE1} .
compileFiles
mkJar %{name}
delBinaryFiles
#<<< end antlr
#<<< end %build

%install
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp %{name}.jar $RPM_BUILD_ROOT%{_javadir}/%{non_bootstrap_name}.jar
ln -sf %{_javadir}/%{non_bootstrap_name}.jar $RPM_BUILD_ROOT/%{_javadir}/%{name}.jar
#<<<

%clean
rm -rf $RPM_BUILD_ROOT 
#>>> files

%files
%defattr(-,root,root)   
#%dir %{_javadir}
%{_javadir}/%{name}.jar
%{_javadir}/%{non_bootstrap_name}.jar
#<<<
# vim:fdm=marker:foldmarker=#>>>,#<<<:foldcolumn=6:

%changelog
* Tue Aug  4 2009 Anas Nashif <anas.nashif@intel.com> - 2.7.7
- Initial import into Moblin
* Mon Mar  3 2008 mvyskocil@suse.cz
- updated to 2.7.7
* Wed Jan 30 2008 adrian@suse.de
- add Provides: antlr on sugggestion of dbornkessel
* Fri May  4 2007 dbornkessel@suse.de
- added unzip to BuildRequires
* Wed Nov 15 2006 dbornkessel@suse.de
- delete "Provides: antlr" ... packages that need the bootstrap package should have a hard require on it
* Thu Oct 12 2006 ro@suse.de
- change buildreq to ">=" for ecj-bootstrap
* Sat Oct  7 2006 dbornkessel@suse.de
- added check that checks whether deleted files ShowString.java and StreamConverter.java are really not in place
* Thu Oct  5 2006 dbornkessel@suse.de
- deleted
  antlr-2.7.6/examples/java/unicode.IDENTs/ShowString.java
  antlr-2.7.6/examples/java/unicode.IDENTs/StreamConverter.java
  from tar ball due to licensing issues (Bug #207621)
* Thu Sep 28 2006 ro@suse.de
- added gcc-gij to BuildRequires
* Wed Sep 20 2006 dbornkessel@suse.de
- renamed antlr-bootstrap.jar to antlr.jar
* Mon Sep 18 2006 dbornkessel@suse.de
- created bootstrapping package
